@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,12 +22,12 @@ from tencentcloud.ccc.v20200210 import models
 
 class CccClient(AbstractClient):
     _apiVersion = '2020-02-10'
-    _endpoint = 'ccc.tencentcloudapi.com'
+    _endpoint = 'ccc.intl.tencentcloudapi.com'
     _service = 'ccc'
 
 
     def AbortAgentCruiseDialingCampaign(self, request):
-        """If you want to stop running agent's individual auto task, then call AbortAgentCruiseDialingCampaign to terminate.
+        """Stop Agent Cruise-style Outbound Call Task
 
         :param request: Request instance for AbortAgentCruiseDialingCampaign.
         :type request: :class:`tencentcloud.ccc.v20200210.models.AbortAgentCruiseDialingCampaignRequest`
@@ -50,7 +50,7 @@ class CccClient(AbstractClient):
 
 
     def AbortPredictiveDialingCampaign(self, request):
-        """This API is used to pause predictive dialing campaign
+        """This API is used to pause the predictive outbound call task.
 
         :param request: Request instance for AbortPredictiveDialingCampaign.
         :type request: :class:`tencentcloud.ccc.v20200210.models.AbortPredictiveDialingCampaignRequest`
@@ -72,8 +72,31 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def BindNumberCallInInterface(self, request):
+        """This API is used to bind a number to a callback API for incoming calls.
+
+        :param request: Request instance for BindNumberCallInInterface.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindNumberCallInInterface", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindNumberCallInInterfaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BindNumberCallOutSkillGroup(self, request):
-        """This API is used to assign outbound skill group(s) to your number
+        """This API is used to bind outbound skill group of number.
 
         :param request: Request instance for BindNumberCallOutSkillGroup.
         :type request: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallOutSkillGroupRequest`
@@ -96,7 +119,7 @@ class CccClient(AbstractClient):
 
 
     def BindStaffSkillGroupList(self, request):
-        """This API is used to assign an agent to skill group
+        """This API is used to bind the agent's skill group.
 
         :param request: Request instance for BindStaffSkillGroupList.
         :type request: :class:`tencentcloud.ccc.v20200210.models.BindStaffSkillGroupListRequest`
@@ -118,6 +141,79 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ControlAIConversation(self, request):
+        """This API is used to provide server-side robot control feature.
+
+        :param request: Request instance for ControlAIConversation.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ControlAIConversationRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ControlAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ControlAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.ControlAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateAIAgentCall(self, request):
+        """This API is used to initiate outbound calls using an AI model, limited to owned phone numbers only. Currently, a limited-time free trial of Advanced Agents is available.
+
+        Before initiating a call, please ensure your AI model is compatible with OpenAI, Azure, or Minimax protocols, and visit the model provider's website to obtain relevant authentication information. For detailed feature descriptions, please refer to the documentation [Tencent Cloud Contact Center AI Call Platform](https://www.tencentcloud.com/document/product/1229/70681).
+
+        :param request: Request instance for CreateAIAgentCall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAIAgentCall", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAIAgentCallResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateAICall(self, request):
+        """Used to make outbound calls by invoking AI models, limited to the use of proprietary phone numbers. Currently, the Advanced version seats are available for a **limited time** free trial.
+
+        Before initiating a call, please ensure your AI model is compatible with OpenAI, Azure, or Minimax protocols, and visit the model provider's website to obtain relevant authentication information. For detailed feature descriptions, please refer to the documentation [Tencent Cloud Contact Center AI Call Platform](https://www.tencentcloud.com/document/product/1229/66889).
+
+        :param request: Request instance for CreateAICall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAICallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAICallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAICall", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAICallResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAdminURL(self, request):
         """This API is used to create a management access link.
 
@@ -142,7 +238,7 @@ class CccClient(AbstractClient):
 
 
     def CreateAgentCruiseDialingCampaign(self, request):
-        """This document shows how to call API to create an individual auto dialing campaign for agent
+        """Agent Cruise-style Outbound Call.
 
         :param request: Request instance for CreateAgentCruiseDialingCampaign.
         :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAgentCruiseDialingCampaignRequest`
@@ -211,7 +307,11 @@ class CccClient(AbstractClient):
 
 
     def CreateCallOutSession(self, request):
-        """This API is used to create outbound sessions. Currently, only dual call is supported. That is, firstly, please use the platform number to call the agent's cell phone. After the agent answers, then please make outbound calls to the user. Due to ISP frequency restrictions, the agent's phone number must first be added to the allowlist to avoid frequency control which may lead to the failure of the outbound call.
+        """This API is used to create an outbound call session. Currently, only dual calls are supported. That is, first use the platform number to call the agent mobile phone. After the agent answers, then make an outbound call to the user. Moreover, due to ISP frequency restrictions, the agent phone number must be added to the allowlist first to avoid frequency control leading to the failure of the outbound call. Therefore, before calling this API, the following operations have been completed.
+        1. The agent specified by UserId has already bound the mobile number. https://intl.cloud.tencent.com/document/product/679/76067?from_cn_redirect=1#.E6.AD.A5.E9.AA.A42.EF.BC.9A.E5.AE.8C.E5.96.84.E8.B4.A6.E5.8F.B7.E4.BF.A1.E6.81.AF.
+        2. The agent's bound mobile number has applied for and passed the outbound call allowlist.
+        This API is used to make calls. Currently, the agent side can only call the user's mobile phone, so the IsForceMobile field must be true.
+        4. Do not fill in the mobile number bound to the current UserId for the callee, otherwise it can lead to call failure due to a busy line.
 
         :param request: Request instance for CreateCallOutSession.
         :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionRequest`
@@ -279,6 +379,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOwnNumberApply(self, request):
+        """Create customer's own number access review
+
+        :param request: Request instance for CreateOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePredictiveDialingCampaign(self, request):
         """This API is used to create the predictive outbound call task.
 
@@ -348,6 +471,52 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateUserSig(self, request):
+        """This API is used to create a user data signature.
+
+        :param request: Request instance for CreateUserSig.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateUserSigRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateUserSigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateUserSig", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateUserSigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteCCCSkillGroup(self, request):
+        """This API is used to delete a skill group.
+
+        :param request: Request instance for DeleteCCCSkillGroup.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCCCSkillGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCCCSkillGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteExtension(self, request):
         """This API is used to delete telephone accounts.
 
@@ -417,6 +586,52 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAICallExtractResult(self, request):
+        """Obtain AI call content extraction result
+
+        :param request: Request instance for DescribeAICallExtractResult.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAICallExtractResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAICallExtractResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAILatency(self, request):
+        """This API is used to obtain AI latency information.
+
+        :param request: Request instance for DescribeAILatency.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAILatency", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAILatencyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAgentCruiseDialingCampaign(self, request):
         """Query Agent Cruise-style Outbound Call Task
 
@@ -739,6 +954,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSessionDetail(self, request):
+        """This API is used to query call detail.
+
+        :param request: Request instance for DescribeSessionDetail.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeSessionDetailRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeSessionDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSessionDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSessionDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSkillGroupInfoList(self, request):
         """This API is used to access the skill group information list.
 
@@ -785,6 +1023,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeStaffStatusHistory(self, request):
+        """This API is used to query agent status history.
+
+        :param request: Request instance for DescribeStaffStatusHistory.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusHistoryRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeStaffStatusHistory", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeStaffStatusHistoryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeStaffStatusMetrics(self, request):
         """This API is used to access the real-time status statistics metrics of the agent.
 
@@ -809,7 +1070,7 @@ class CccClient(AbstractClient):
 
 
     def DescribeTelCallInfo(self, request):
-        """This API is used to access call detail records by application
+        """This API is used to access telephone consumption statistics by instance.
 
         :param request: Request instance for DescribeTelCallInfo.
         :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeTelCallInfoRequest`
@@ -854,6 +1115,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTelRecordAsr(self, request):
+        """Pull conversation recording for text information
+
+        :param request: Request instance for DescribeTelRecordAsr.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTelRecordAsr", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTelRecordAsrResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTelSession(self, request):
         """This API is used to access the PSTN session information.
 
@@ -900,6 +1184,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ForceMemberOffline(self, request):
+        """This API is used to force customer service to go offline.
+
+        :param request: Request instance for ForceMemberOffline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ForceMemberOffline", params, headers=headers)
+            response = json.loads(body)
+            model = models.ForceMemberOfflineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def HangUpCall(self, request):
         """This API is used to hang up the phone.
 
@@ -946,8 +1253,31 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyOwnNumberApply(self, request):
+        """Modify customer's own number approval form
+
+        :param request: Request instance for ModifyOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyStaff(self, request):
-        """This API is used to modify  customer service / agent account.
+        """This API is used to modify the customer service account.
 
         :param request: Request instance for ModifyStaff.
         :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyStaffRequest`
@@ -1038,6 +1368,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreMemberOnline(self, request):
+        """This API is used to restore customer service to go live.
+
+        :param request: Request instance for RestoreMemberOnline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreMemberOnline", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreMemberOnlineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResumePredictiveDialingCampaign(self, request):
         """This API is used to resume the predictive outbound call task.
 
@@ -1084,6 +1437,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def TransferToManual(self, request):
+        """This API is used to transfer a session to an agent in specific scenarios.
+
+        :param request: Request instance for TransferToManual.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.TransferToManualRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.TransferToManualResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("TransferToManual", params, headers=headers)
+            response = json.loads(body)
+            model = models.TransferToManualResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UnbindNumberCallOutSkillGroup(self, request):
         """This API is used to unbind the number from the outbound call skill group.
 
