@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,12 @@ FAILEDOPERATION_GETCLSTOPICFAILED = 'FailedOperation.GetClsTopicFailed'
 # Failed to pull the COS bucket list
 FAILEDOPERATION_GETCOSBUCKETLISTFAILED = 'FailedOperation.GetCosBucketListFailed'
 
+# 
+FAILEDOPERATION_MEMBERNOTAUDITROLE = 'FailedOperation.MemberNotAuditRole'
+
+# 
+FAILEDOPERATION_MEMBERNOTINORGANIZATION = 'FailedOperation.MemberNotInOrganization'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -158,5 +164,11 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # The tracking set does not exist.
 RESOURCENOTFOUND_AUDITNOTEXIST = 'ResourceNotFound.AuditNotExist'
 
+# 
+RESOURCENOTFOUND_COSNOTEXIST = 'ResourceNotFound.CosNotExist'
+
 # The role doesn’t exist.
 RESOURCENOTFOUND_ROLENOTEXIST = 'ResourceNotFound.RoleNotExist'
+
+# 
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
