@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.csip.v20221121 import models
 
 class CsipClient(AbstractClient):
     _apiVersion = '2022-11-21'
-    _endpoint = 'csip.tencentcloudapi.com'
+    _endpoint = 'csip.intl.tencentcloudapi.com'
     _service = 'csip'
 
 
@@ -302,6 +302,52 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeOrganizationInfo(self, request):
+        """Check group account details
+
+        :param request: Request instance for DescribeOrganizationInfo.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeOrganizationInfoRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeOrganizationInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOrganizationInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOrganizationInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeOrganizationUserInfo(self, request):
+        """Query group account user list
+
+        :param request: Request instance for DescribeOrganizationUserInfo.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeOrganizationUserInfoRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeOrganizationUserInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOrganizationUserInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOrganizationUserInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribePublicIpAssets(self, request):
         """This API is used to query the list of public IP assets.
 
@@ -578,6 +624,29 @@ class CsipClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSubUserInfo(self, request):
+        """Query the group's sub-account list
+
+        :param request: Request instance for DescribeSubUserInfo.
+        :type request: :class:`tencentcloud.csip.v20221121.models.DescribeSubUserInfoRequest`
+        :rtype: :class:`tencentcloud.csip.v20221121.models.DescribeSubUserInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSubUserInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSubUserInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSubnetAssets(self, request):
         """This API is used to get the list of subnets.
 
