@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.dcdb.v20180411 import models
 
 class DcdbClient(AbstractClient):
     _apiVersion = '2018-04-11'
-    _endpoint = 'dcdb.tencentcloudapi.com'
+    _endpoint = 'dcdb.intl.tencentcloudapi.com'
     _service = 'dcdb'
 
 
@@ -257,6 +257,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOnlineDDLJob(self, request):
+        """This API is used to create an online DDL job.
+
+        :param request: Request instance for CreateOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAccount(self, request):
         """This API is used to delete a TencentDB account, which is uniquely identified by username and host.
 
