@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -56,6 +56,9 @@ FAILEDOPERATION_COMPARELOWSIMILARITY = 'FailedOperation.CompareLowSimilarity'
 # Error calling the comparison engine API.
 FAILEDOPERATION_COMPARESYSTEMERROR = 'FailedOperation.CompareSystemError'
 
+# The video compression failed. Please try again or reduce the size of the input video.
+FAILEDOPERATION_COMPRESSVIDEOERROR = 'FailedOperation.CompressVideoError'
+
 # The face in the picture is blocked, please upload a picture without any blockage
 FAILEDOPERATION_COVEREDFACE = 'FailedOperation.CoveredFace'
 
@@ -182,6 +185,9 @@ FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'
 # Video decoding abnormality
 FAILEDOPERATION_VIDEODECODEFAILED = 'FailedOperation.VideoDecodeFailed'
 
+# 
+FAILEDOPERATION_VIDEODURATIONEXCEEDED = 'FailedOperation.VideoDurationExceeded'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
