@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,9 @@ FAILEDOPERATION = 'FailedOperation'
 # This operation cannot be performed across algorithm model versions.
 FAILEDOPERATION_ACROSSVERSIONSERROR = 'FailedOperation.AcrossVersionsError'
 
+# 
+FAILEDOPERATION_COMPAREFAIL = 'FailedOperation.CompareFail'
+
 # The operations conflict. Do not operate on the same person simultaneously.
 FAILEDOPERATION_CONFLICTOPERATION = 'FailedOperation.ConflictOperation'
 
@@ -65,6 +68,18 @@ FAILEDOPERATION_IMAGERESOLUTIONTOOSMALL = 'FailedOperation.ImageResolutionTooSma
 # The size of the Base64-encoded image cannot exceed 5 MB.
 FAILEDOPERATION_IMAGESIZEEXCEED = 'FailedOperation.ImageSizeExceed'
 
+# 
+FAILEDOPERATION_LIFEPHOTODETECTFACES = 'FailedOperation.LifePhotoDetectFaces'
+
+# 
+FAILEDOPERATION_LIFEPHOTODETECTFAKE = 'FailedOperation.LifePhotoDetectFake'
+
+# 
+FAILEDOPERATION_LIFEPHOTODETECTNOFACES = 'FailedOperation.LifePhotoDetectNoFaces'
+
+# 
+FAILEDOPERATION_LIFEPHOTOSIZEERROR = 'FailedOperation.LifePhotoSizeError'
+
 # The request frequency exceeds the limit.
 FAILEDOPERATION_REQUESTLIMITEXCEEDED = 'FailedOperation.RequestLimitExceeded'
 
@@ -245,7 +260,7 @@ RESOURCEUNAVAILABLE_CHARGESTATUSEXCEPTION = 'ResourceUnavailable.ChargeStatusExc
 # The resource is being shipped.
 RESOURCEUNAVAILABLE_DELIVERING = 'ResourceUnavailable.Delivering'
 
-# The account is frozen.
+# The account has been frozen.
 RESOURCEUNAVAILABLE_FREEZE = 'ResourceUnavailable.Freeze'
 
 # Failed to get the authentication information.
@@ -266,7 +281,7 @@ RESOURCEUNAVAILABLE_NOTREADY = 'ResourceUnavailable.NotReady'
 # The resource has been repossessed.
 RESOURCEUNAVAILABLE_RECOVER = 'ResourceUnavailable.Recover'
 
-# The service has been suspended for the account.
+# Services for the account has been stopped.
 RESOURCEUNAVAILABLE_STOPUSING = 'ResourceUnavailable.StopUsing'
 
 # The billing status is unknown.
