@@ -29,8 +29,7 @@ class IaiClient(AbstractClient):
     def AnalyzeFace(self, request):
         """This API is used to perform facial feature localization (aka facial keypoint localization) on a given image and calculate 90 facial keypoints that make up the contour of the face, including eyebrows (8 points on the left and 8 on the right), eyes (8 points on the left and 8 on the right), nose (13 points), mouth (22 points), face contour (21 points), and eyeballs or pupils (2 points).
 
-        >
-        - Please use the signature algorithm v3 to calculate the signature in the common parameters, that is, set the `SignatureMethod` parameter to `TC3-HMAC-SHA256`.
+        >- Please use the signature algorithm v3 to calculate the signature in the common parameters, that is, set the `SignatureMethod` parameter to `TC3-HMAC-SHA256`.
 
         :param request: Request instance for AnalyzeFace.
         :type request: :class:`tencentcloud.iai.v20200303.models.AnalyzeFaceRequest`
@@ -82,8 +81,7 @@ class IaiClient(AbstractClient):
 
     def CopyPerson(self, request):
         """This API is used to copy a person in a group to another group (without copying the description). One person can exist in up to 100 groups at the same time.
-        >
-        - Note: in the case that the version of the algorithm model was 2.0 when the person was created, the copy operation will fail if the target group is not of algorithm model 2.0.
+        >- Note: in the case that the version of the algorithm model was 2.0 when the person was created, the copy operation will fail if the target group is not of algorithm model 2.0.
 
         :param request: Request instance for CopyPerson.
         :type request: :class:`tencentcloud.iai.v20200303.models.CopyPersonRequest`
