@@ -450,6 +450,30 @@ class IntlpartnersmgtClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCustomerOwnVoucherList(self, request):
+        """This API is used to query the voucher list by Customer.
+        Callable roles: Customer.
+
+        :param request: Request instance for DescribeCustomerOwnVoucherList.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeCustomerOwnVoucherListRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeCustomerOwnVoucherListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCustomerOwnVoucherList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCustomerOwnVoucherListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCustomerUin(self, request):
         """This API is used to query the list of customer UINs.
 
@@ -473,6 +497,30 @@ class IntlpartnersmgtClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCustomerVoucherList(self, request):
+        """This API is used to query the customer voucher list by Reseller, Second-level Reseller or Distributor.
+        Callable roles: Reseller, Second-level Reseller or Distributor.
+
+        :param request: Request instance for DescribeCustomerVoucherList.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeCustomerVoucherListRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeCustomerVoucherListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCustomerVoucherList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCustomerVoucherListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRebateDownloadUrl(self, request):
         """This API is used to download the commission bill file by resellers/agents. The file URL is returned.
         Resellers/Agents can call this API.
@@ -742,7 +790,7 @@ class IntlpartnersmgtClient(AbstractClient):
 
 
     def QueryInvitationInfo(self, request):
-        """Query usage information of invitation link. Once created, the data will only be retained for 60 days, and the system will automatically delete the invitation link after 60 days.
+        """Query usage information of invitation link. Invitation link is valid for 30 days.And once created, the data will only be retained for 60 days, and the system will automatically delete the invitation link after 60 days.
         Invokable role types: Distributor, Second-level reseller, Reseller.
 
         :param request: Request instance for QueryInvitationInfo.
