@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,15 +22,15 @@ from tencentcloud.lighthouse.v20200324 import models
 
 class LighthouseClient(AbstractClient):
     _apiVersion = '2020-03-24'
-    _endpoint = 'lighthouse.tencentcloudapi.com'
+    _endpoint = 'lighthouse.intl.tencentcloudapi.com'
     _service = 'lighthouse'
 
 
     def ApplyInstanceSnapshot(self, request):
         """This API is used to roll back the system disk snapshot of the specified instance.
-        <li>Only rollback to the original system disk is supported.</li>
+        <li>Only rollback to the original system disk is supported. </li>
         <li>Only snapshots in `NORMAL` status can be used for rollback. To query the status of a snapshot, you can call the `DescribeSnapshots` API and see the `SnapshotState` field in the response.</li>
-        <li>When a snapshot is rolled back, the status of the instance must be `STOPPED` or `RUNNING`. You can call the `DescribeInstances` API to query the instance status. Instances in `RUNNING` status will be forcibly shut down before snapshot rollback.</li>
+        <li>When a snapshot is rolled back, the status of the instance must be `STOPPED` or `RUNNING`. You can call the `DescribeInstances` API to query the instance status. Instances in `RUNNING` status will be forcibly shut down before snapshot rollback. </li>
 
         :param request: Request instance for ApplyInstanceSnapshot.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.ApplyInstanceSnapshotRequest`
