@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,10 +22,33 @@ from tencentcloud.tag.v20180813 import models
 
 class TagClient(AbstractClient):
     _apiVersion = '2018-08-13'
-    _endpoint = 'tag.tencentcloudapi.com'
+    _endpoint = 'tag.intl.tencentcloudapi.com'
     _service = 'tag'
 
 
+    def AddProject(self, request):
+        """Creates a project
+
+        :param request: Request instance for AddProject.
+        :type request: :class:`tencentcloud.tag.v20180813.models.AddProjectRequest`
+        :rtype: :class:`tencentcloud.tag.v20180813.models.AddProjectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddProject", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddProjectResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AddResourceTag(self, request):
         """This API is used to associate resources with tags.
 
