@@ -62,6 +62,9 @@ INTERNALERROR_ASYNCHRONOUSCALLFAILED = 'InternalError.AsynchronousCallFailed'
 # DBErr
 INTERNALERROR_DBERR = 'InternalError.DBErr'
 
+# InternalError.Unknown
+INTERNALERROR_UNKNOWN = 'InternalError.Unknown'
+
 # An internal error exists. Please contact us.
 INTERNALERROR_UNKNOWNERR = 'InternalError.UnknownErr'
 
@@ -119,6 +122,9 @@ INVALIDPARAMETER_XFFRESETPARAMETERERR = 'InvalidParameter.XFFResetParameterErr'
 # Invalid parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# InvalidRequest
+INVALIDPARAMETERVALUE_INVALIDREQUEST = 'InvalidParameterValue.InvalidRequest'
+
 # The quota limit is exceeded.
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -146,6 +152,9 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # Resources do not exist.
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# ResourceNotFound.NotFound
+RESOURCENOTFOUND_NOTFOUND = 'ResourceNotFound.NotFound'
+
 # Resources are unavailable.
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
