@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.waf.v20180125 import models
 
 class WafClient(AbstractClient):
     _apiVersion = '2018-01-25'
-    _endpoint = 'waf.tencentcloudapi.com'
+    _endpoint = 'waf.intl.tencentcloudapi.com'
     _service = 'waf'
 
 
@@ -210,6 +210,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOwaspWhiteRule(self, request):
+        """This API is used to add a rule engine allowlist.
+
+        :param request: Request instance for CreateOwaspWhiteRule.
+        :type request: :class:`tencentcloud.waf.v20180125.models.CreateOwaspWhiteRuleRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.CreateOwaspWhiteRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOwaspWhiteRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOwaspWhiteRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAntiFakeUrl(self, request):
         """Delete tamper-proof URL
 
@@ -371,6 +394,52 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteOwaspRuleStatus(self, request):
+        """This API is used to unlock the Door God rule status.
+
+        :param request: Request instance for DeleteOwaspRuleStatus.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DeleteOwaspRuleStatusRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DeleteOwaspRuleStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteOwaspRuleStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteOwaspRuleStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteOwaspWhiteRule(self, request):
+        """This API is used to delete a user rule engine allowlist.
+
+        :param request: Request instance for DeleteOwaspWhiteRule.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DeleteOwaspWhiteRuleRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DeleteOwaspWhiteRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteOwaspWhiteRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteOwaspWhiteRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteSession(self, request):
         """Delete CC attack session settings
 
@@ -440,60 +509,6 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeAntiFakeUrl(self, request):
-        """废弃接口
-
-        This API has been deprecated.
-
-        Obtain a tamper-proof URL
-
-        :param request: Request instance for DescribeAntiFakeUrl.
-        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeAntiFakeUrlRequest`
-        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeAntiFakeUrlResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeAntiFakeUrl", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeAntiFakeUrlResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def DescribeAntiInfoLeakRules(self, request):
-        """老接口已经不再使用。
-
-        The old API is no longer in use.
-
-        Obtain the information leakage prevention rule list
-
-        :param request: Request instance for DescribeAntiInfoLeakRules.
-        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeAntiInfoLeakRulesRequest`
-        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeAntiInfoLeakRulesResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeAntiInfoLeakRules", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeAntiInfoLeakRulesResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeAntiInfoLeakageRules(self, request):
         """Obtain the information leakage prevention rule list
 
@@ -517,6 +532,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAttackOverview(self, request):
+        """This API is used to describe the attack overview.
+
+        :param request: Request instance for DescribeAttackOverview.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeAttackOverviewRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeAttackOverviewResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAttackOverview", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAttackOverviewResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAttackType(self, request):
         """Query the top N attack types for a specified domain
 
@@ -1023,6 +1061,75 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeOwaspRuleTypes(self, request):
+        """This API is used to query the rule types of the rule engine.
+
+        :param request: Request instance for DescribeOwaspRuleTypes.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspRuleTypesRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspRuleTypesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOwaspRuleTypes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOwaspRuleTypesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeOwaspRules(self, request):
+        """This API is used to query the rule list of the rule engine.
+
+        :param request: Request instance for DescribeOwaspRules.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspRulesRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOwaspRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOwaspRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeOwaspWhiteRules(self, request):
+        """This API is used to retrieve the allowlist for the rule engine.
+
+        :param request: Request instance for DescribeOwaspWhiteRules.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspWhiteRulesRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeOwaspWhiteRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOwaspWhiteRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOwaspWhiteRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribePeakPoints(self, request):
         """Query business and attack summary trends
 
@@ -1368,6 +1475,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetAttackHistogram(self, request):
+        """This API is used to generate a bar chart for the generation time of attack logs.
+
+        :param request: Request instance for GetAttackHistogram.
+        :type request: :class:`tencentcloud.waf.v20180125.models.GetAttackHistogramRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.GetAttackHistogramResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetAttackHistogram", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetAttackHistogramResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetAttackTotalCount(self, request):
         """Display total attack count by querying based on conditions
 
@@ -1690,6 +1820,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDomainPostAction(self, request):
+        """This API is used to modify the domain shipping status.
+
+        :param request: Request instance for ModifyDomainPostAction.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyDomainPostActionRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyDomainPostActionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDomainPostAction", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDomainPostActionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDomainsCLSStatus(self, request):
         """Enable or disable access log for domain list
 
@@ -1967,6 +2120,121 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyOwaspRuleStatus(self, request):
+        """This API is used to refresh the rule switch.
+
+        :param request: Request instance for ModifyOwaspRuleStatus.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleStatusRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwaspRuleStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwaspRuleStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyOwaspRuleTypeAction(self, request):
+        """This API is used to update the protection mode of the rule type.
+
+        :param request: Request instance for ModifyOwaspRuleTypeAction.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeActionRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeActionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwaspRuleTypeAction", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwaspRuleTypeActionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyOwaspRuleTypeLevel(self, request):
+        """This API is used to update the protection level of a rule type.
+
+        :param request: Request instance for ModifyOwaspRuleTypeLevel.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeLevelRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeLevelResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwaspRuleTypeLevel", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwaspRuleTypeLevelResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyOwaspRuleTypeStatus(self, request):
+        """This API is used to update the rule type switch.
+
+        :param request: Request instance for ModifyOwaspRuleTypeStatus.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeStatusRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspRuleTypeStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwaspRuleTypeStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwaspRuleTypeStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyOwaspWhiteRule(self, request):
+        """This API is used to edit the allowlist for the rule engine.
+
+        :param request: Request instance for ModifyOwaspWhiteRule.
+        :type request: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspWhiteRuleRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.ModifyOwaspWhiteRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwaspWhiteRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwaspWhiteRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyProtectionStatus(self, request):
         """This API is used to obtain the enabling status of the basic security protection module of WAF.
 
@@ -2128,6 +2396,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SearchAttackLog(self, request):
+        """The new version of the CLS API has parameter changes, with query changed to query_string to support Lucene syntax for API search queries.
+
+        :param request: Request instance for SearchAttackLog.
+        :type request: :class:`tencentcloud.waf.v20180125.models.SearchAttackLogRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.SearchAttackLogResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SearchAttackLog", params, headers=headers)
+            response = json.loads(body)
+            model = models.SearchAttackLogResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SwitchElasticMode(self, request):
         """Toggle elasticity switch
 
